@@ -74,13 +74,15 @@ gesture_callback (GtkWidget        *widget,
             GripEventGesturePinch *e = (GripEventGesturePinch *)event;
             GtkWindow *toplevel = (GtkWindow *)gtk_widget_get_toplevel (widget);
             gint window_width, window_height;
-            AxisExtents *x = grip_input_device_get_x_extents (e->input_device);
-            AxisExtents *y = grip_input_device_get_y_extents (e->input_device);
+            const GripAxisExtents *x;
+            const GripAxisExtents *y;
             gfloat width = 0;
             gfloat height = 0;
             gfloat factor = 0;
 
             gtk_window_get_size (toplevel, &window_width, &window_height);
+            x = grip_input_device_get_x_extents (e->input_device);
+            y = grip_input_device_get_y_extents (e->input_device);
             width = window_width / (x->maximum - x->minimum);
             height = window_height / (y->maximum - y->minimum);
             factor = sqrtf (width * width + height * height) / 5.2723;
@@ -183,8 +185,8 @@ create_window (struct app_data *app)
   g_signal_connect (window, "destroy", G_CALLBACK (gtk_widget_destroyed), &window);
   g_signal_connect (window, "destroy", G_CALLBACK (gtk_main_quit), NULL);
 
-  hbox = gtk_hbox_new (FALSE, 0);
-  vbox = gtk_vbox_new (FALSE, 0);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 
   gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (hbox), app->da, TRUE, TRUE, 0);
