@@ -35,6 +35,23 @@ grip_time_type_get_type(void) {
     }
   return enum_type_id;
 }
+/* enumerations from "gripinputdevice.h" */
+#include "gripinputdevice.h"
+GType
+grip_device_type_get_type(void) {
+  static GType enum_type_id = 0;
+  if (G_UNLIKELY (!enum_type_id))
+    {
+      static const GEnumValue values[] = {
+        { GRIP_DEVICE_TOUCHSCREEN, "GRIP_DEVICE_TOUCHSCREEN", "touchscreen" },
+        { GRIP_DEVICE_TOUCHPAD, "GRIP_DEVICE_TOUCHPAD", "touchpad" },
+        { GRIP_DEVICE_INDEPENDENT, "GRIP_DEVICE_INDEPENDENT", "independent" },
+        { 0, NULL, NULL }
+      };
+      enum_type_id = g_enum_register_static (g_intern_static_string ("GripDeviceType"), values);
+    }
+  return enum_type_id;
+}
 
 /* Generated data ends here */
 
